All of lore.kernel.org
 help / color / mirror / Atom feed
From: Sebastian Andrzej Siewior <bigeasy@linutronix.de>
To: Tatyana Brokhman <tlinder@codeaurora.org>
Cc: gregkh@suse.de, linux-arm-msm@vger.kernel.org, balbi@ti.com,
	ablay@codeaurora.org, linux-usb@vger.kernel.org,
	linux-kernel@vger.kernel.org,
	Sebastian Andrzej Siewior <bigeasy@linutronix.de>
Subject: [PATCH 3/5] usb/gadget: rename create_ss_descriptors() to usb_create_ss_descriptors()
Date: Tue, 12 Apr 2011 21:34:54 +0200	[thread overview]
Message-ID: <1302636896-12717-4-git-send-email-bigeasy@linutronix.de> (raw)
In-Reply-To: <1302636896-12717-1-git-send-email-bigeasy@linutronix.de>

so have a namespace.

Signed-off-by: Sebastian Andrzej Siewior <bigeasy@linutronix.de>
---
 drivers/usb/gadget/composite.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/usb/gadget/composite.c b/drivers/usb/gadget/composite.c
index d12e75a4..92cc238 100644
--- a/drivers/usb/gadget/composite.c
+++ b/drivers/usb/gadget/composite.c
@@ -80,7 +80,7 @@ static struct usb_ss_ep_comp_descriptor default_ep_comp_desc = {
 };
 
 /**
  * create_ss_descriptors() - Generate SuperSpeed descriptors
  * with default values
  * @f: pointer to usb_function to generate the descriptors for
  *
@@ -91,7 +91,7 @@ static struct usb_ss_ep_comp_descriptor default_ep_comp_desc = {
  * This function copies f->hs_descriptors while updating the
  * endpoint descriptor and adding endpoint companion descriptor.
  */
-static void create_ss_descriptors(struct usb_function *f)
+void usb_create_ss_descriptors(struct usb_function *f)
 {
 	struct usb_ss_ep_comp_descriptor	*ep_comp_desc;
 	struct usb_endpoint_descriptor		*ep_desc;
@@ -80,7 +80,7 @@ static struct usb_ss_ep_comp_descriptor default_ep_comp_desc = {
 
 /**
- * create_ss_descriptors() - Generate SuperSpeed descriptors
+ * usb_create_ss_descriptors() - Generate SuperSpeed descriptors
  * with default values
  * @f: pointer to usb_function to generate the descriptors for
-- 
1.7.4

  parent reply	other threads:[~2011-04-12 19:34 UTC|newest]

Thread overview: 28+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2011-03-23  8:04 [PATCH 5/5 v5] usb:gadget: Add SuperSpeed support to the Gadget Framework Tatyana Brokhman
2011-03-23  8:04 ` Tatyana Brokhman
     [not found] ` <1300867498-20997-1-git-send-email-tlinder-sgV2jX0FEOL9JmXXK+q4OQ@public.gmane.org>
2011-03-25 13:41   ` Felipe Balbi
2011-03-25 13:41     ` Felipe Balbi
2011-03-28  8:45     ` Tanya Brokhman
2011-03-28  8:45       ` Tanya Brokhman
2011-03-28  8:54       ` Felipe Balbi
2011-03-28  9:15         ` Tanya Brokhman
2011-03-28  9:15           ` Tanya Brokhman
2011-04-11 17:59   ` Sebastian Andrzej Siewior
2011-04-11 17:59     ` Sebastian Andrzej Siewior
2011-04-12 19:34     ` Sebastian Andrzej Siewior
2011-04-12 19:34       ` [PATCH 2/5] usb/gadget: rename bos to get_bos_descr in composite Sebastian Andrzej Siewior
2011-04-12 19:34       ` Sebastian Andrzej Siewior [this message]
2011-04-12 19:34       ` [PATCH 4/5] usb/gadget: don't deploy SS descriptors if SS is not enabled Sebastian Andrzej Siewior
2011-04-13 10:46         ` Sergei Shtylyov
     [not found]           ` <4DA57F0F.1090609-hkdhdckH98+B+jHODAdFcQ@public.gmane.org>
2011-04-13 10:56             ` Sebastian Andrzej Siewior
2011-04-13 10:56               ` Sebastian Andrzej Siewior
2011-04-13 10:59               ` Michal Nazarewicz
     [not found]       ` <1302636896-12717-1-git-send-email-bigeasy-hfZtesqFncYOwBW4kG4KsQ@public.gmane.org>
2011-04-12 19:34         ` [PATCH 1/5] usb/gadget: cleanup of "Add SuperSpeed support to the Gadget Framework" Sebastian Andrzej Siewior
2011-04-12 19:34           ` Sebastian Andrzej Siewior
2011-04-13  8:17           ` Felipe Balbi
2011-04-12 19:34         ` [PATCH 5/5] usb/gadget: don't auto-create SS descriptors if HS are avilable Sebastian Andrzej Siewior
2011-04-12 19:34           ` Sebastian Andrzej Siewior
2011-04-13 11:12       ` [PATCH 5/5 v5] usb:gadget: Add SuperSpeed support to the Gadget Framework Tanya Brokhman
2011-04-13 11:12         ` Tanya Brokhman
2011-04-14  7:36     ` Tanya Brokhman
2011-04-14  7:36       ` Tanya Brokhman

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1302636896-12717-4-git-send-email-bigeasy@linutronix.de \
    --to=bigeasy@linutronix.de \
    --cc=ablay@codeaurora.org \
    --cc=balbi@ti.com \
    --cc=gregkh@suse.de \
    --cc=linux-arm-msm@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-usb@vger.kernel.org \
    --cc=tlinder@codeaurora.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.